@@ -1,7 +1,7 @@
 package App::btcindo;
 
-our $DATE = '2017-11-23'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2017-11-24'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 1;
 # ABSTRACT: CLI for bitcoin.co.id
@@ -18,7 +18,7 @@ App::btcindo - CLI for bitcoin.co.id
 
 =head1 VERSION
 
-This document describes version 0.006 of App::btcindo (from Perl distribution App-btcindo), released on 2017-11-23.
+This document describes version 0.007 of App::btcindo (from Perl distribution App-btcindo), released on 2017-11-24.
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ feature.
 
 =head1 SEE ALSO
 
-L<Finance::BTCInfo>
+L<Finance::BTCIndo>
 
 =head1 AUTHOR
 
